summaryrefslogtreecommitdiffhomepage
path: root/pkg/usermem/usermem_arm64.go
diff options
context:
space:
mode:
authorAyush Ranjan <ayushranjan@google.com>2021-03-03 10:23:55 -0800
committergVisor bot <gvisor-bot@google.com>2021-03-03 10:25:58 -0800
commita9441aea2780da8c93da1c73da860219f98438de (patch)
tree8b12915756f5bfb926218214cd7bc0b3281605fd /pkg/usermem/usermem_arm64.go
parentb8a5420f49a2afd622ec08b5019e1bf537f7da82 (diff)
[op] Replace syscall package usage with golang.org/x/sys/unix in pkg/.
The syscall package has been deprecated in favor of golang.org/x/sys. Note that syscall is still used in the following places: - pkg/sentry/socket/hostinet/stack.go: some netlink related functionalities are not yet available in golang.org/x/sys. - syscall.Stat_t is still used in some places because os.FileInfo.Sys() still returns it and not unix.Stat_t. Updates #214 PiperOrigin-RevId: 360701387
Diffstat (limited to 'pkg/usermem/usermem_arm64.go')
-rw-r--r--pkg/usermem/usermem_arm64.go7
1 files changed, 4 insertions, 3 deletions
diff --git a/pkg/usermem/usermem_arm64.go b/pkg/usermem/usermem_arm64.go
index fdfc30a66..7e7529585 100644
--- a/pkg/usermem/usermem_arm64.go
+++ b/pkg/usermem/usermem_arm64.go
@@ -18,13 +18,14 @@ package usermem
import (
"encoding/binary"
- "syscall"
+
+ "golang.org/x/sys/unix"
)
const (
// PageSize is the system page size.
// arm64 support 4K/16K/64K page size,
// which can be get by syscall.Getpagesize().
// Currently, only 4K page size is supported.
PageSize = 1 << PageShift
@@ -47,7 +48,7 @@ var (
func init() {
// Make sure the page size is 4K on arm64 platform.
- if size := syscall.Getpagesize(); size != PageSize {
+ if size := unix.Getpagesize(); size != PageSize {
panic("Only 4K page size is supported on arm64!")
}
}
@@ -18,13 +18,14 @@ package usermem
// PageSize is the system page size.
// arm64 support 4K/16K/64K page size,
- // which can be get by syscall.Getpagesize().
+ // which can be get by unix.Getpagesize().
// Currently, only 4K page size is supported.
PageSize = 1 << PageShift